@@ -696,7 +696,7 @@ class wait_job_events(Command):  # pylint: disable=invalid-name
     Wait for job to finish and return job details.
     """
 
-    FINISHED_JOB_STATUS = ["Complete", "Incomplete", "Canceled"]
+    FINISHED_JOB_STATE = "Finished"
     EVENT_SOCKET_PATTERN_SYMBOL = "*"
 
     def reparse_arguments(self, parser, raw_args):
@@ -740,16 +740,16 @@ class wait_job_events(Command):  # pylint: disable=invalid-name
 
         # Need to get the host in case of shortcuts usage.
         host = get_server_url(auth_backend, self.args.SERVER)
-        hostname = urlparse.urlparse(host).netloc
+        hostname = urlparse.urlparse(host).hostname
 
         if self.args.job_id:
             job_ids = [self.args.job_id]
             try:
                 job = server.scheduler.job_details(self.args.job_id)
 
-                if job["status"] in self.FINISHED_JOB_STATUS:
-                    print("Job %s already finished with status %s." % (
-                        self.args.job_id, job["status"]))
+                if job["state"] == self.FINISHED_JOB_STATE:
+                    print("Job %s already finished with state %s." % (
+                        self.args.job_id, job["health"]))
                     return
 
             except xmlrpclib.Fault:
@@ -801,7 +801,7 @@ class wait_job_events(Command):  # pylint: disable=invalid-name
                 sock.setsockopt(zmq.SUBSCRIBE, b"")  # pylint: disable=no-member
                 sock.connect(event_socket)
 
-                print("Now waiting for job events...\n")
+                print("Now waiting for job events...")
                 while True:
                     msg = sock.recv_multipart()
                     try:
@@ -817,11 +817,11 @@ class wait_job_events(Command):  # pylint: disable=invalid-name
                             if data["job"] in job_ids:
                                 data["job"] = urlparse.urljoin(
                                     job_url_template, str(data["job"]))
-                                if data["status"] in self.FINISHED_JOB_STATUS:
-                                    print(data, "\n")
+                                if data["state"] == self.FINISHED_JOB_STATE:
+                                    print(data)
                                     break
                                 elif not self.args.quiet:
-                                    print(data, "\n")
+                                    print(data)
 
         except zmq.error.ZMQError as exc:
             sys.stderr.write("wait_job_events() error: %s\n" % exc)
@@ -834,8 +834,8 @@ class wait_job_events(Command):  # pylint: disable=invalid-name
             try:
                 for job_id in job_ids:
                     ret_details = server.scheduler.job_details(job_id)
-                    print("Job %s currently has status %s." % (
-                        job_id, ret_details["status"]))
+                    print("Job %s currently has state %s." % (
+                        job_id, ret_details["state"]))
                     print("You can check the job details with 'lava-tool job-details' command.")
                 return 1
             except xmlrpclib.Fault:
