@@ -101,6 +101,8 @@ def validate_single_url(url):
                                         stderr=subprocess.STDOUT)
             except subprocess.CalledProcessError as exc:
                 sys.stderr.write("Warning: %s\n" % exc)
+            except OSError as exc:
+                sys.stderr.write("Missing git executable: %s\n" % exc)
         else:
             try:
                 res = requests.head(url[0], allow_redirects=True,
