@@ -17,7 +17,6 @@
 # along with lava-tool.  If not, see <http://www.gnu.org/licenses/>.
 
 import getpass
-import urllib
 import urlparse
 import xmlrpclib
 
@@ -28,13 +27,9 @@ from lava_tool.authtoken import (
     DuplicateEndpointShortcutError,
     DuplicateUserShortcutError,
     EndpointNotFoundError,
-    UsernameNotFoundError,
-    ConfigOptionsNotProvidedError,
     normalize_xmlrpc_url,
     split_xmlrpc_url,
-    USERNAME_OPTION_DEFAULT,
     USERNAME_OPTION_SHORT,
-    ENDPOINT_OPTION_SHORT,
     CONFIG_OPTIONS
 )
 from lava_tool.interface import Command, LavaCommandError
